@@ -4,7 +4,7 @@
 # import classes.
 # keep this import style so you can also use the keys.Keys() etc directly.
 from ssht00ls import classes
-from ssht00ls.classes import encryption
+from ssht00ls.classes import ssht00ls_agent, network_info
 
 # import initialized classes & objects.
 from ssht00ls.classes.installation import installation
@@ -21,8 +21,13 @@ from ssht00ls.classes.ssync import ssync
 from ssht00ls.classes.smb import smb
 from ssht00ls.classes.client import clients, Client
 
+# shortcuts.
+push = ssync.push
+pull = ssync.pull
+
 # source path & version.
-import fil3s
-source_path = fil3s.gfp.base(__file__)
-try: version = fil3s.Files.load(source_path+".version.py").replace("\n","").replace(" ","")
+from dev0s import Version, Directory, Files, gfp
+source = Directory(gfp.base(__file__))
+base = Directory(source.fp.base())
+try: version = Version(Files.load(source.join(".version.py")))
 except: version = None
\ No newline at end of file
