@@ -6,15 +6,15 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 
 # the ssh connections object class.
-class Connections(syst3m.objects.Traceback):
+class Connections(Traceback):
 	def __init__(self):
 		
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.connections", raw_traceback="ssht00ls.classes.connections.Connections")
+		Traceback.__init__(self, traceback="ssht00ls.connections", raw_traceback="ssht00ls.classes.connections.Connections")
 
 		#
 	def list(self, filter="ssh"):
-		output = syst3m.utils.__execute_script__("""ss | grep ssh | awk '{print $1","$2","$3","$4","$5","$6}' """)
+		output = dev0s.utils.__execute_script__("""ss | grep ssh | awk '{print $1","$2","$3","$4","$5","$6}' """)
 		connections = {}
 		for line in output.split("\n"):
 			if line not in [""]:
@@ -27,7 +27,7 @@ class Connections(syst3m.objects.Traceback):
 						"sendq":sendq,
 						"net_id":net_id,
 					}
-		return r3sponse.success(f"Successfully listed {len(connections)} ssh connection(s).", {
+		return Response.success(f"Successfully listed {len(connections)} ssh connection(s).", {
 			"connections":connections,
 		})
 
