@@ -6,12 +6,12 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 
 # the installation object class.
-class Installation(syst3m.objects.Traceback):
+class Installation(Traceback):
 	def __init__(self,
 	):
 		
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.installation", raw_traceback="ssht00ls.classes.installation.Installation")
+		Traceback.__init__(self, traceback="ssht00ls.installation", raw_traceback="ssht00ls.classes.installation.Installation")
 
 		#
 	def install(self, 
@@ -19,8 +19,8 @@ class Installation(syst3m.objects.Traceback):
 		username=None,
 	):
 		# initialize.
-		if username == None: username = syst3m.defaults.vars.user
-		home = f"{syst3m.defaults.vars.homes}/{username}/"	
+		if username == None: username = Defaults.vars.user
+		home = f"{Defaults.vars.homes}/{username}/"	
 		sudo = True
 		
 		# users ssh directory.
@@ -79,7 +79,7 @@ class Installation(syst3m.objects.Traceback):
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		return r3sponse.success(f"Successfully installed ssh for user [{username}].")
+		return Response.success(f"Successfully installed ssh for user [{username}].")
 
 		#
 	def check_installed(self, 
@@ -88,14 +88,14 @@ class Installation(syst3m.objects.Traceback):
 	):	
 
 		# initialize.
-		if username == None: username = syst3m.defaults.vars.user
-		home = f"{syst3m.defaults.vars.homes}/{username}/"	
+		if username == None: username = Defaults.vars.user
+		home = f"{Defaults.vars.homes}/{username}/"	
 		sudo = True
 		
 		# users ssh directory.
 		fp = FilePath(f"{home}.ssh/")
 		if not fp.exists():
-			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return Response.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=700, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -103,7 +103,7 @@ class Installation(syst3m.objects.Traceback):
 		# the ssh config.
 		fp = FilePath(f"{home}.ssh/config")
 		if not fp.exists():
-			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return Response.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -111,7 +111,7 @@ class Installation(syst3m.objects.Traceback):
 		# the ssh known hosts.
 		fp = FilePath(f"{home}.ssh/known_hosts")
 		if not fp.exists():
-			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return Response.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=644, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
@@ -119,13 +119,13 @@ class Installation(syst3m.objects.Traceback):
 		# authorized keys.
 		fp = FilePath(f"{home}.ssh/authorized_keys")
 		if not fp.exists():
-			return r3sponse.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
+			return Response.error(f"Required ssh configuration file [{fp.path}] for user [{username}] is not installed.")
 		else:
 			fp.permission.set(permission=600, sudo=sudo)
 			fp.ownership.set(owner=username, group=None, sudo=sudo)
 
 		# success.
-		return r3sponse.success(f"SSH is successfully installed for user [{username}].")
+		return Response.success(f"SSH is successfully installed for user [{username}].")
 			
 # Initialized objects.
 installation = Installation()
