@@ -7,7 +7,7 @@ from ssht00ls.classes import utils
 from ssht00ls.classes.smartcards import smartcards
 
 # the ssh key object class.
-class Keys(syst3m.objects.Traceback):
+class Keys(Traceback):
 	def __init__(self,
 		# initialize as specific not global (optional).
 		#	the username.
@@ -19,7 +19,7 @@ class Keys(syst3m.objects.Traceback):
 	):
 
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.keys", raw_traceback="ssht00ls.classes.keys.Keys")
+		Traceback.__init__(self, traceback="ssht00ls.keys", raw_traceback="ssht00ls.classes.keys.Keys")
 
 		# specific variables.
 		self.specific = username != None
@@ -38,7 +38,7 @@ class Keys(syst3m.objects.Traceback):
 		path = Formats.denitialize(path)
 		old = Formats.denitialize(old)
 		new = Formats.denitialize(new)
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"old":old,
 			"new":new,
 			"path":path,
@@ -53,18 +53,18 @@ class Keys(syst3m.objects.Traceback):
 
 		# check fails.
 		if "incorrect passphrase supplied" in output:
-			return r3sponse.error(f"Provided an incorrect passphrase for key [{path}].")
+			return Response.error(f"Provided an incorrect passphrase for key [{path}].")
 		elif "No such file or directory" in output:
-			return r3sponse.error(f"Key [{path}] does not exist.")
+			return Response.error(f"Key [{path}] does not exist.")
 		
 		# check success.	
 		elif "Your identification has been saved with the new passphrase" in output:
-			return r3sponse.success(f"Successfully edited the passphrase of key [{path}].")
+			return Response.success(f"Successfully edited the passphrase of key [{path}].")
 
 		# unknown.
 		else:
 			l = f"Failed to edit the passphrase of key [{path}]"
-			return r3sponse.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
+			return Response.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
 
 			
 		
@@ -79,7 +79,7 @@ class Keys(syst3m.objects.Traceback):
 		path = Formats.denitialize(path)
 		passphrase = Formats.denitialize(passphrase)
 		comment = Formats.denitialize(comment)
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"old":old,
 			"passphrase":passphrase,
 			"comment":comment,
@@ -94,18 +94,18 @@ class Keys(syst3m.objects.Traceback):
 
 		# check fails.
 		if "incorrect passphrase supplied" in output:
-			return r3sponse.error(f"Provided an incorrect passphrase for key [{path}].")
+			return Response.error(f"Provided an incorrect passphrase for key [{path}].")
 		elif "No such file or directory" in output:
-			return r3sponse.error(f"Key [{path}] does not exist.")
+			return Response.error(f"Key [{path}] does not exist.")
 		
 		# check success.	
 		elif "Comment '" in output and "' applied" in output:
-			return r3sponse.success(f"Successfully edited the comment of key [{path}].")
+			return Response.success(f"Successfully edited the comment of key [{path}].")
 
 		# unknown.
 		else:
 			l = f"Failed to edit the comment of key [{path}]"
-			return r3sponse.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
+			return Response.error((f"{l}, error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
 
 			
 		
@@ -121,7 +121,7 @@ class Keys(syst3m.objects.Traceback):
 		passphrase = Formats.denitialize(passphrase)
 		comment = Formats.denitialize(comment)
 		if directory[len(directory)-1] != "/": directory += "/"
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"path":directory,
 		}, traceback=self.__traceback__(function="generate"))
 		if not response["success"]: return response
@@ -132,13 +132,13 @@ class Keys(syst3m.objects.Traceback):
 
 		# create dir.
 		if directory != None and Files.exists(f"{directory}/public_key"): 
-			return r3sponse.error(f"Public key [{directory}/public_key] already exists.")
+			return Response.error(f"Public key [{directory}/public_key] already exists.")
 		elif directory != None and Files.exists(f"{directory}/private_key"): 
-			return r3sponse.error(f"Private key [{directory}/private_key] already exists.")
+			return Response.error(f"Private key [{directory}/private_key] already exists.")
 		elif directory != None and not Files.exists(directory): 
 			os.mkdir(directory)
 			Files.chmod(path=directory, permission=700, sudo=True)
-			Files.chown(path=directory, owner=syst3m.defaults.vars.user, group=None, sudo=True)
+			Files.chown(path=directory, owner=Defaults.vars.user, group=None, sudo=True)
 
 		# options.
 		private_key = f'{directory}/private_key'
@@ -152,19 +152,19 @@ class Keys(syst3m.objects.Traceback):
 		# execute.
 		os.system(f'ssh-keygen -q -v -o -a 100 -t ed25519 {passphrase} {identity_file} {comment}')
 		if not Files.exists(private_key): 
-			return r3sponse.error(f"Failed to generate key [{directory}].")
+			return Response.error(f"Failed to generate key [{directory}].")
 
 		# permissions.
 		Files.chmod(path=private_key, permission=600, sudo=True)
-		Files.chown(path=private_key, owner=syst3m.defaults.vars.user, group=None, sudo=True)
+		Files.chown(path=private_key, owner=Defaults.vars.user, group=None, sudo=True)
 		os.system(f"mv '{private_key}.pub' '{public_key}'")
 		if not Files.exists(public_key): 
-			return r3sponse.error(f"Failed to move private key [{private_key}].")
+			return Response.error(f"Failed to move private key [{private_key}].")
 		Files.chmod(path=public_key, permission=640, sudo=True)
-		Files.chown(path=public_key, owner=syst3m.defaults.vars.user, group=None, sudo=True)
+		Files.chown(path=public_key, owner=Defaults.vars.user, group=None, sudo=True)
 
 		# response.
-		return r3sponse.success(f"Successfully generated key [{directory}].")
+		return Response.success(f"Successfully generated key [{directory}].")
 
 		#
 	def check(self, username=None, public_keys=[], reversed=False):
@@ -174,10 +174,10 @@ class Keys(syst3m.objects.Traceback):
 			if username == None: username = self.username
 
 		# check if already present.
-		if username == None: username = syst3m.defaults.vars.user
+		if username == None: username = Defaults.vars.user
 		username = Formats.denitialize(username)
-		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
-		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
+		ssh_dir = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/authorized_keys")
 		output = self.__load_keys__(username)
 		for key in public_keys:
 			key = key.replace("\n", "")
@@ -187,13 +187,13 @@ class Keys(syst3m.objects.Traceback):
 					auth_keys.permission.set(permission=600, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.ownership.set(owner=username, sudo=True)
 					ssh_dir.ownership.set(owner=username, sudo=True)
-					return r3sponse.error(f'Public key [{key}] is not activated.')
+					return Response.error(f'Public key [{key}] is not activated.')
 				if reversed and key in output:
 					ssh_dir.permission.set(permission=700, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.permission.set(permission=600, sudo=True, silent=True) # silent for when non existant.
 					auth_keys.ownership.set(owner=username, sudo=True)
 					ssh_dir.ownership.set(owner=username, sudo=True)
-					return r3sponse.error(f'Public key [{key}] is activated.')
+					return Response.error(f'Public key [{key}] is activated.')
 
 		# set correct permission.
 		ssh_dir.permission.set(permission=700, sudo=True, silent=True) # silent for when non existant.
@@ -203,9 +203,9 @@ class Keys(syst3m.objects.Traceback):
 
 		# success.
 		if not reversed:
-			return r3sponse.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are activated.')
+			return Response.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are activated.')
 		else:
-			return r3sponse.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are not activated.')
+			return Response.success(f'Successfully confirmed that the specfied {len(public_keys)} public key(s) are not activated.')
 	def enable(self, username=None, public_keys=[]):
 
 		# check specific.
@@ -215,7 +215,7 @@ class Keys(syst3m.objects.Traceback):
 				public_keys = Array(Files.load(self.public_key).split("\n")).clean(remove_first=[" "], remove_last=[" "])
 
 		# check if already present.
-		if username == None: username = syst3m.defaults.vars.user
+		if username == None: username = Defaults.vars.user
 		output = self.__load_keys__(username)
 		new_keys = []
 		for key in public_keys:
@@ -230,7 +230,7 @@ class Keys(syst3m.objects.Traceback):
 		if response["error"] != None: return response
 	
 		# success.
-		return r3sponse.success(f'Successfully enabled {len(public_keys)} public key(s).')
+		return Response.success(f'Successfully enabled {len(public_keys)} public key(s).')
 
 		#
 	def disable(self, username=None, public_keys=[]):
@@ -242,7 +242,7 @@ class Keys(syst3m.objects.Traceback):
 				public_keys = Array(Files.load(self.public_key).split("\n")).clean(remove_first=[" "], remove_last=[" "])
 
 		# check if already present.
-		if username == None: username = syst3m.defaults.vars.user
+		if username == None: username = Defaults.vars.user
 		output = self.__load_keys__(username)
 		new_keys = []
 		for key in output:
@@ -256,16 +256,16 @@ class Keys(syst3m.objects.Traceback):
 		if response["error"] != None: return response
 	
 		# success.
-		return r3sponse.success(f'Successfully disabled {len(public_keys)} public key(s).')
+		return Response.success(f'Successfully disabled {len(public_keys)} public key(s).')
 
 		#
 	def __load_keys__(self, username):
 
 		# make readable.
-		if username == None: username = syst3m.defaults.vars.user
-		sudo = syst3m.defaults.vars.user != username or True
-		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
-		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
+		if username == None: username = Defaults.vars.user
+		sudo = Defaults.vars.user != username or True
+		ssh_dir = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/authorized_keys")
 
 		# checks.
 		if not ssh_dir.exists(sudo=sudo):
@@ -286,22 +286,22 @@ class Keys(syst3m.objects.Traceback):
 
 		ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
-		auth_keys.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
-		ssh_dir.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
+		auth_keys.ownership.set(owner=Defaults.vars.user, sudo=sudo)
+		ssh_dir.ownership.set(owner=Defaults.vars.user, sudo=sudo)
 
 		if sudo: command = ["sudo"]
 		else: command = []
-		output = utils.__execute__(command + ["cat", f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys"], return_format="array")
+		output = utils.__execute__(command + ["cat", f"{Defaults.vars.homes}/{username}/.ssh/authorized_keys"], return_format="array")
 		return output
 
 		#
 	def __save_keys__(self, username, public_keys):
 
 		# make readable.
-		if username == None: username = syst3m.defaults.vars.user
-		sudo = syst3m.defaults.vars.user != username or True
-		ssh_dir = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/")
-		auth_keys = FilePath(f"{syst3m.defaults.vars.homes}/{username}/.ssh/authorized_keys")
+		if username == None: username = Defaults.vars.user
+		sudo = Defaults.vars.user != username or True
+		ssh_dir = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/")
+		auth_keys = FilePath(f"{Defaults.vars.homes}/{username}/.ssh/authorized_keys")
 
 		# checks.
 		if not ssh_dir.exists(sudo=sudo):
@@ -329,8 +329,8 @@ class Keys(syst3m.objects.Traceback):
 
 		ssh_dir.permission.set(permission=700, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=600, sudo=sudo, silent=True) # silent for when non existant.
-		auth_keys.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
-		ssh_dir.ownership.set(owner=syst3m.defaults.vars.user, sudo=sudo)
+		auth_keys.ownership.set(owner=Defaults.vars.user, sudo=sudo)
+		ssh_dir.ownership.set(owner=Defaults.vars.user, sudo=sudo)
 
 		#
 
