@@ -8,7 +8,7 @@ from ssht00ls.classes.ssh import ssh, Tunnel
 from ssht00ls.classes.aliases import aliases
 
 # the smb client object class.
-class SMB(syst3m.objects.Thread):
+class SMB(Thread):
 	def __init__(self,
 		# initialize as specific not global (optional).
 		# 	the share id (#1).
@@ -31,11 +31,11 @@ class SMB(syst3m.objects.Thread):
 		# 	the reconnect reattemps.
 		reattemps=15,
 		# 	the log level.
-		log_level=syst3m.defaults.options.log_level,
+		log_level=Defaults.options.log_level,
 	):
 
 		# defaults.
-		syst3m.objects.Thread.__init__(self, traceback="ssht00ls.smb", log_level=syst3m.defaults.log_level(default=-1))
+		Thread.__init__(self, traceback="ssht00ls.smb", log_level=Defaults.log_level(default=-1))
 
 		# specific variables.
 		self.specific = alias != None and id != None and path != None and ip != None
@@ -89,10 +89,10 @@ class SMB(syst3m.objects.Thread):
 
 		# loader.
 		if log_level >= 0:
-			loader = syst3m.console.Loader(f"Mounting smb share [{alias}:{id}] to [{path}]")
+			loader = Console.Loader(f"Mounting smb share [{alias}:{id}] to [{path}]")
 
 		# checks.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"id:str,String":id,
 			"path:str,String":path,
 			"alias:str,String":alias,
@@ -119,11 +119,11 @@ class SMB(syst3m.objects.Thread):
 			return response
 		elif response.mounted:
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Path [{path}] is already mounted.")
+			return Response.error(f"Path [{path}] is already mounted.")
 		elif not response.exists:
-			os.system(f"mkdir -p {path} 2> /dev/null && chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {path}")
+			os.system(f"mkdir -p {path} 2> /dev/null && chown {Defaults.vars.user}:{Defaults.vars.group} {path}")
 			if not os.path.exists(path):
-				os.system(f"sudo mkdir -p {path} 2> /dev/null && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {path}")
+				os.system(f"sudo mkdir -p {path} 2> /dev/null && sudo chown {Defaults.vars.user}:{Defaults.vars.group} {path}")
 
 		# check tunnel.
 		if tunnel:
@@ -131,7 +131,7 @@ class SMB(syst3m.objects.Thread):
 			if not self.specific or (self.specific and self.tunnel_obj == None):
 				# check already established tunnel from previous session.
 				established_port = None
-				response = syst3m.defaults.processes(includes=f":localhost:445 -f -N {DEFAULT_SSH_OPTIONS} {alias}")
+				response = Code.processes(includes=f":localhost:445 -f -N {DEFAULT_SSH_OPTIONS} {alias}")
 				if not response.success: 
 					if log_level >= 0: loader.stop(success=False)
 					return response
@@ -171,13 +171,13 @@ class SMB(syst3m.objects.Thread):
 				time.sleep(0.5)
 				if reconnect and new_tunnel:
 					#tunnel_.start()
-					response = webserver.start_thread(tunnel_, group="tunnels", id=tunnel_.id)
+					response = ssht00ls_agent.webserver.start_thread(tunnel_, group="tunnels", id=tunnel_.id)
 					if not response.success: 
 						if log_level >= 0: loader.stop(success=False)
 						return response
 
 		# command.
-		if syst3m.defaults.vars.os in ["macos"]:
+		if Defaults.vars.os in ["macos"]:
 			if password == None:
 				user_pass = username
 			elif password == "":
@@ -187,15 +187,15 @@ class SMB(syst3m.objects.Thread):
 			command = f"mount_smbfs //{user_pass}@{ip}:{port}/{id} {path}"
 		else:
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error("Coming soon.")
+			return Response.error("Coming soon.")
 			command = ""
 
 		# execute.
 		try:
-			output = syst3m.console.execute(command)
+			output = Code.execute(command)
 		except KeyboardInterrupt as e:
-			if syst3m.defaults.vars.os in ["macos"]:
-				syst3m.defaults.kill(includes=command, log_level=-1)
+			if Defaults.vars.os in ["macos"]:
+				Code.kill(includes=command, log_level=-1)
 			raise KeyboardInterrupt(e)
 		if not output.success: 
 			if log_level >= 0: loader.stop(success=False)
@@ -217,7 +217,7 @@ class SMB(syst3m.objects.Thread):
 					reconnect=reconnect,)
 			if reconnect:
 				#smb.start()
-				response = webserver.start_thread(smb, group="smb.mounts", id=path)
+				response = ssht00ls_agent.webserver.start_thread(smb, group="smb.mounts", id=path)
 				if not response.success: 
 					if log_level >= 0: loader.stop(success=False)
 					return response
@@ -227,7 +227,7 @@ class SMB(syst3m.objects.Thread):
 		if not self.specific and tunnel: attributes["tunnel"] = tunnel_
 		if not self.specific and reconnect: attributes["smb"] = smb
 		if log_level >= 0: loader.stop()
-		return r3sponse.success(f"Successfully mounted smb share [{alias}:{id}] to [{path}].", attributes)
+		return Response.success(f"Successfully mounted smb share [{alias}:{id}] to [{path}].", attributes)
 
 		#
 	def unmount(self, 
@@ -247,10 +247,10 @@ class SMB(syst3m.objects.Thread):
 
 		# loader.
 		if log_level >= 0:
-			loader = syst3m.console.Loader(f"Unmounting [{path}]")
+			loader = Console.Loader(f"Unmounting [{path}]")
 
 		# checks.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"path:str,String":path,
 			"forced:bool,Boolean":forced,
 			"sudo:bool,Boolean":sudo,
@@ -266,12 +266,12 @@ class SMB(syst3m.objects.Thread):
 			return response
 		elif not response.mounted:
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Path [{path}] is not mounted.")
+			return Response.error(f"Path [{path}] is not mounted.")
 
 		# check stop thread.
 		"""
 		smb = None
-		response = webserver.get_thread(group="smb.mounts", id=path)
+		response = ssht00ls_agent.webserver.get_thread(group="smb.mounts", id=path)
 		print(response)
 		if not response.success and "There is no thread cached for" not in response.error:
 			return response
@@ -279,7 +279,7 @@ class SMB(syst3m.objects.Thread):
 			smb = response.thread
 		if smb != None:
 			response = smb.stop()
-			r3sponse.log(response=response)
+			Response.log(response=response)
 			if not response.success: return response
 		"""
 
@@ -291,18 +291,18 @@ class SMB(syst3m.objects.Thread):
 		if forced: 
 			command += "-f "
 		command += path
-		output = syst3m.console.execute(command)
+		output = Code.execute(command)
 
 		# handlers.
 		if not output:
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Failed to unmount [{path}], error: {output}")
+			return Response.error(f"Failed to unmount [{path}], error: {output}")
 		if output != "":
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error((f"Failed to unmount [{path}], error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
+			return Response.error((f"Failed to unmount [{path}], error: "+output.replace("\n", ". ").replace(". .", ".")+".)").replace(". .",".").replace("\r","").replace("..","."))
 		else:
 			if log_level >= 0: loader.stop()
-			return r3sponse.success(f"Successfully unmounted [{path}].")
+			return Response.success(f"Successfully unmounted [{path}].")
 
 		#
 	def parse(self,
@@ -314,7 +314,7 @@ class SMB(syst3m.objects.Thread):
 		if path == None: path = self.path
 
 		# checks.
-		response = r3sponse.parameters.check({
+		response = Response.parameters.check({
 			"path:str,String":path,
 		}, traceback=self.__traceback__(function="unmount"))
 		if not response["success"]: return response
@@ -324,7 +324,7 @@ class SMB(syst3m.objects.Thread):
 		except FileNotFoundError: mounted = False
 		try: directory = os.path.isdir(path)
 		except FileNotFoundError: directory = False
-		return r3sponse.success(f"Successfully parsed [{path}].", {
+		return Response.success(f"Successfully parsed [{path}].", {
 			"exists":os.path.exists(path),
 			"mounted":mounted,
 			"directory":directory,
@@ -336,7 +336,7 @@ class SMB(syst3m.objects.Thread):
 
 		# checks.
 		if not self.mounted:
-			self.send_crash(response=r3sponse.error_response("The smb share is not mounted yet."))
+			self.send_crash(response=Response.error_response("The smb share is not mounted yet."))
 
 		# start.
 		while self.run_permission:
@@ -370,7 +370,7 @@ class SMB(syst3m.objects.Thread):
 		# do not kill the tunnel since it may be used by other mounts.
 		response = self.unmount()
 		if not response.success and "is not mounted" not in response.error: return response
-		return r3sponse.success(f"Successfully stopped [{self.id}]")
+		return Response.success(f"Successfully stopped [{self.id}]")
 	# properties.
 	@property
 	def id(self):
