@@ -80,20 +80,20 @@ def stop(path, timeout=SSYNC_DAEMON_SLEEPTIME*10, sleeptime=1):
 			break
 		time.sleep(sleeptime)
 	if stopped:
-		return r3sponse.success(f"Successfully stopped ssht00ls daemon [{path}].")
+		return Response.success(f"Successfully stopped ssht00ls daemon [{path}].")
 	else:
-		return r3sponse.error(f"Failed to stop ssht00ls daemon [{path}].")
+		return Response.error(f"Failed to stop ssht00ls daemon [{path}].")
 
 # the daemon object class.
-class Daemon(syst3m.objects.Thread):
+class Daemon(Thread):
 	def __init__(self, attributes={}):
 
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.ssync.daemons.Daemon", raw_traceback="ssht00ls.classes.ssync.daemons.Daemon")
+		Traceback.__init__(self, traceback="ssht00ls.ssync.daemons.Daemon", raw_traceback="ssht00ls.classes.ssync.daemons.Daemon")
 
 		# attributes.
 		self.utils = ssync_utils
-		syst3m.objects.Thread.__init__(self)
+		Thread.__init__(self)
 		self.assign(attributes)
 		self.path = gfp.clean(self.path)
 		self.id = f"{self.alias}:{self.remote} {self.path}"
@@ -120,7 +120,7 @@ class Daemon(syst3m.objects.Thread):
 
 		# logs.
 		if self.log_level >= 0: 
-			loader = syst3m.console.Loader(f"Checking daemon {self.id}", interactive=INTERACTIVE)
+			loader = Console.Loader(f"Checking daemon {self.id}", interactive=INTERACTIVE)
 
 		# checks.
 		status = str(cache.get(id=self.cache_path, group="daemons"))
@@ -173,7 +173,7 @@ class Daemon(syst3m.objects.Thread):
 			# sync.
 			response = self.sync(attempts=3, delay=[3, 5, 10])
 			if self.log_level >= 1:
-				r3sponse.log(response=response)
+				Response.log(response=response)
 			if not response["success"]: 
 				self.crash(f"ssht00ls daemon ({self.id}) encountered an error while synchronizing: {response.error}", unmount=False)
 
@@ -219,7 +219,7 @@ class Daemon(syst3m.objects.Thread):
 				time.sleep(0.5)
 				response = self.delete(self.path, remote=False, subpath=False,)
 				if not response["success"]: return response
-		return r3sponse.success("Successfully unmounted.")
+		return Response.success("Successfully unmounted.")
 	def delete(self, path, remote=False, subpath=True):
 
 		# sandbox.
@@ -239,11 +239,11 @@ class Daemon(syst3m.objects.Thread):
 			if remote:
 				msg = f"Sandbox enabled, skip deletion of {self.alias}:{str_id}."
 				if self.log_level >= 0: print(msg)
-				return r3sponse.success(msg)
+				return Response.success(msg)
 			else:
 				msg = f"Sandbox enabled, skip deletion of {str_id}."
 				if self.log_level >= 0: print(msg)
-				return r3sponse.success(msg)
+				return Response.success(msg)
 
 		# logs.
 		if self.log_level >= 1:
@@ -264,18 +264,14 @@ class Daemon(syst3m.objects.Thread):
 						cmd += f""" && printf 'y' | rm -fr '{i}'"""
 					c += 1
 				cmd += ' " '
-			response = self.utils.execute(
-				command=cmd,
-				error=f"Failed to delete {self.alias}:{str_id}.",
-				message=f"Successfully deleted {self.alias}:{str_id}.",
-				get_output=True,)
+			response = self.utils.execute(command=cmd,)
 			if not response["success"]: return response
 			#response = ssh.utils.test_path(alias=self.alias, path=path)
 			#if response.error != None and f"{path} does not exist" not in response.error:
-			#	return r3sponse.error(f"Failed to delete {self.alias}:{path}, error: {response.error}")
+			#	return Response.error(f"Failed to delete {self.alias}:{path}, error: {response.error}")
 			if response.output != "":
-				return r3sponse.error(f"Failed to delete {self.alias}:{str_id}, error: {output}")
-			return r3sponse.success(f"Successfully deleted {self.alias}:{str_id}")
+				return Response.error(f"Failed to delete {self.alias}:{str_id}, error: {output}")
+			return Response.success(f"Successfully deleted {self.alias}:{str_id}")
 
 		# remote to local.
 		else:
@@ -289,15 +285,11 @@ class Daemon(syst3m.objects.Thread):
 					else:
 						cmd += f""" && printf 'y' | rm -fr '{i}'"""
 					c += 1
-			response = self.utils.execute(
-				command=cmd,
-				error=f"Failed to delete {str_id}.",
-				message=f"Successfully deleted {str_id}.",
-				get_output=True,)
+			response = self.utils.execute(command=cmd)
 			if not response["success"]: return response
 			if response.output != "":
-				return r3sponse.error(f"Failed to delete {str_id}, error: {output}")
-			return r3sponse.success(f"Successfully deleted {str_id}")
+				return Response.error(f"Failed to delete {str_id}, error: {output}")
+			return Response.success(f"Successfully deleted {str_id}")
 	def index(self, short=False):
 
 		# index.
@@ -316,7 +308,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				clean_index[subpath] = index[path]
 			except KeyError:
-				return r3sponse.error(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
+				return Response.error(f"Should not happen(#278363). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
 		for path, mtime in remote_index.items():
 			subpath = self.subpath(path)
 			if subpath not in all_paths: 
@@ -325,7 +317,7 @@ class Daemon(syst3m.objects.Thread):
 			try:
 				remote_clean_index[subpath] = remote_index[path]
 			except KeyError:
-				return r3sponse.error(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
+				return Response.error(f"Should not happen(#739639). (subpath: {subpath}), (path: {path}), (index: {index}), (remote index: {remote_index}).")
 
 		# mismatches.
 		synchronized, mismatches = self.mismatches(clean_index, remote_clean_index, all_paths)
@@ -338,7 +330,7 @@ class Daemon(syst3m.objects.Thread):
 				self.last_index["0"] = clean_index
 			if self.last_remote_index == {}:
 				self.last_remote_index["0"] = remote_clean_index
-			return r3sponse.success(f"Successfully indexed [{self.alias}:{self.path}] & [{self.path}].", {
+			return Response.success(f"Successfully indexed [{self.alias}:{self.path}] & [{self.path}].", {
 				"synchronized":synchronized,
 				"index":index,
 				"remote_index":remote_index,
@@ -405,7 +397,7 @@ class Daemon(syst3m.objects.Thread):
 						"local_mtime":lmtime,
 						"remote_mtime":rmtime,
 					}
-		return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {mismatches}].")
+		return Response.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {mismatches}].")
 		"""
 	def process_mismatches(self, clean_index, remote_clean_index, mismatches):
 
@@ -432,7 +424,7 @@ class Daemon(syst3m.objects.Thread):
 			# should not happen.
 			if rmtime == None and lmtime == None: 
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
+				return Response.error(f"No remote & local modification time present. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# one missing.
 			elif rmtime == None or lmtime == None:
@@ -466,7 +458,7 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
+					return Response.error(f"Should not happen (#3243443). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# both present.
 			elif rmtime != None and lmtime != None:
@@ -486,12 +478,12 @@ class Daemon(syst3m.objects.Thread):
 				# should not happen.
 				else:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
+					return Response.error(f"Unable to compare rmtime: {rmtime} & lmtime: {lmtime}. (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# exceptions.
 			else:
 				self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-				return r3sponse.error(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
+				return Response.error(f"Should not happen (#407294). (path: {subpath}), (rmtime: {rmtime}), (lmtime: {lmtime}), (last_rmtime: {last_rmtime}), (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 
 			# do not remove this exception.
 			# it is required for safe edits, to make sure a dir never gets synced unless it is created / removed.
@@ -503,7 +495,7 @@ class Daemon(syst3m.objects.Thread):
 				# add to updates.
 				if local_to_remote and remote_to_local:
 					self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-					return r3sponse.error(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
+					return Response.error(f"Can not synchronize both remote to local & local to remote (rmtime: {rmtime}) (lmtime: {lmtime}), (last_rmtime: {last_rmtime}) (last_lmtime: {last_lmtime}), index: {clean_index}, remote index: {remote_clean_index}.")
 				if "delete" in options: 
 					if self.log_level >= 1: 
 						if local_to_remote:
@@ -530,7 +522,7 @@ class Daemon(syst3m.objects.Thread):
 						"empty_directory":empty_directory,}
 		# handler.
 		self.set_last_index(clean_index) ; self.set_last_index(remote_clean_index, remote=True)
-		return r3sponse.success(f"Successfully indexed [{self.alias}:{rfullpath}] & [{lfullpath}].", {
+		return Response.success(f"Successfully indexed [{self.alias}:{rfullpath}] & [{lfullpath}].", {
 			"synchronized":len(updates) == 0 and len(deletions) == 0,
 			"updates":updates,
 			"deletions":deletions,
@@ -660,9 +652,9 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level > 0:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
+				return Response.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
 			else:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
+				return Response.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		"""
 
 		# get index.
@@ -672,9 +664,9 @@ class Daemon(syst3m.objects.Thread):
 			if self.log_level >= 1:
 				print(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 			if self.log_level >= 3:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
+				return Response.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized, index: {response.index}, remote index: {response.remote_index}.")
 			else:
-				return r3sponse.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
+				return Response.success(f"Directories [{self.alias}:{self.path}] & [{self.path}] are already synchronized.")
 		updates,deletions = response.unpack(["updates", "deletions"])
 		if multiprocessing and len(updates) < 50:
 			if self.log_level >= 0:
@@ -718,7 +710,7 @@ class Daemon(syst3m.objects.Thread):
 						inside_batch_size += 1
 					del depths[str(depth)]
 			if depths != {}:
-				return r3sponse.error(f"Should not happen(#234938). (depths: {depths}), (updates: {updates}).")
+				return Response.error(f"Should not happen(#234938). (depths: {depths}), (updates: {updates}).")
 
 			# add directories.
 			for path, info in dir_updates.items():
@@ -829,12 +821,12 @@ class Daemon(syst3m.objects.Thread):
 				else:
 					remote_deletions.append(path)
 			if local_deletions != []:
-				if self.log_level >= 0: loader = syst3m.console.Loader(f"Deleting {len(local_deletions)} local file(s).")
+				if self.log_level >= 0: loader = Console.Loader(f"Deleting {len(local_deletions)} local file(s).")
 				response = self.delete(local_deletions, remote=False)
 				if self.log_level >= 0: loader.stop(success=response["success"])
 				if not response["success"]: return response
 			if remote_deletions != []:
-				if self.log_level >= 0: loader = syst3m.console.Loader(f"Deleting {len(remote_deletions)} remote file(s).")
+				if self.log_level >= 0: loader = Console.Loader(f"Deleting {len(remote_deletions)} remote file(s).")
 				response = self.delete(remote_deletions, remote=True)
 				if self.log_level >= 0: loader.stop(success=response["success"])
 				if not response["success"]: return response
@@ -853,27 +845,8 @@ class Daemon(syst3m.objects.Thread):
 		response = self.index(short=True)
 		if not response["success"]: return response
 		elif not response.synchronized:
-			return r3sponse.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {response.mismatches}].")
+			return Response.error(f"Failed to synchronize [{self.alias}:{self.remote}] & [{self.path}], mismatches: {response.mismatches}].")
 
 		# handler.
-		return r3sponse.success(f"Successfully synchronized [{self.alias}:{self.path}] & [{self.path}].")
-	# DEPCIRATED.
-	def synchronized(self): # does not work.
-		response = self.utils.execute(
-			command=f"printf 'yes' | rsync -avun --delete {self.alias}:{self.remote} {self.path} --timeout={SSH_TIMEOUT}",
-			error="",
-			message=f"Successfully checked [{self.alias}:{self.remote}] & [{self.path}]",
-			get_output=True,)
-		if not response["success"]: return response
-		output = response["output"]
-		if "receiving incremental file list" not in output or "total size is" not in output or "bytes/sec" not in output:
-			return r3sponse.error(f"Unkown rsync output: [{output}].")
-		b = output.split("\n")
-		try:
-			output = output[len(b[0])+1:-(len(b[len(b)-1])+len(b[len(b)-2])+3)]
-		except Exception as e:
-			return r3sponse.error(f"Failed to clean rsync output: [{output}]. Error: {e}; ")
-		print("OUTPUT:",output)
-		return r3sponse.success(f"Successfully checked [{self.alias}:{self.remote}] & [{self.path}]", {
-			"synchronized":output == "",
-		})
\ No newline at end of file
+		return Response.success(f"Successfully synchronized [{self.alias}:{self.path}] & [{self.path}].")
+	
\ No newline at end of file
