@@ -17,6 +17,4 @@ class WebServer(syst3m.cache.WebServer):
 			"default":{},
 			"port":52379,
 		})
-	def start_daemon(self, daemon, group="daemons", id=None):
-		self.__cache__.set(group=group, id=id, data=daemon)
-		daemon.start()
+	# could be expanded.
